precision mediump float;

varying vec2 v_TextureCoordinates;
uniform sampler2D u_InputTexture;
uniform float uWidth; // 纹理宽
uniform float uHeight; // 纹理高

float cY(float x,float y){
    vec4 c=texture2D(u_InputTexture,vec2(x,y));
    // return c.r*0.2990+c.g*0.5870+c.b*0.1140;
    return c.r*0.2568+c.g*0.5041+c.b*0.0979 + 0.06779;
}

float cU(float x,float y){
    vec4 c=texture2D(u_InputTexture,vec2(x,y));
    return -0.1479*c.r - 0.2896*c.g + 0.4375*c.b+0.5000;
    // return -0.1471*c.r - 0.2889*c.g + 0.4360*c.b+0.5000;
}

float cV(float x,float y){
    vec4 c=texture2D(u_InputTexture,vec2(x,y));
    return 0.4375*c.r - 0.3666*c.g - 0.0709*c.b+0.5000;
    // return 0.6150*c.r - 0.5150*c.g - 0.1000*c.b+0.5000;
}

vec2 cPos(float t,float shiftx,float shifty){
    vec2 pos=vec2(uWidth*v_TextureCoordinates.x,uHeight*(v_TextureCoordinates-shifty));
    return vec2(mod(pos.x*shiftx,uWidth),(pos.y*shiftx+floor(pos.x*shiftx/uWidth))*t);
}

vec4 calculateY(){
    // 填充点对应图片的位置
    float posX=floor(uWidth*v_TextureCoordinates.x);
    float posY=floor(uHeight*v_TextureCoordinates.y);
    // 实际采样起始点对应图片的位置
    float rPosX=mod(posX*4.,uWidth);
    float rPosY=posY*4.+floor(posX*4./uWidth);
    vec4 oColor=vec4(0);
    float textureYPos=rPosY/uHeight;
    oColor[0]=cY(rPosX/uWidth,textureYPos);
    oColor[1]=cY((rPosX+1.)/uWidth,textureYPos);
    oColor[2]=cY((rPosX+2.)/uWidth,textureYPos);
    oColor[3]=cY((rPosX+3.)/uWidth,textureYPos);
    return oColor;
}

vec4 calculateU(){
    // U的采样，宽度是1:8，高度是1:2，U的位置高度偏移了1/4，一个点是4个U，采样区域是宽高位8*2
    float posX=floor(uWidth*v_TextureCoordinates.x);
    float posY=floor(uHeight*(v_TextureCoordinates.y-0.2500));
    // 实际采样起始点对应图片的位置
    float rPosX=mod(posX*8.,uWidth);
    float rPosY=posY*16.+floor(posX*8./uWidth)*2.;
    vec4 oColor=vec4(0);
    oColor[0]= cU(rPosX/uWidth,rPosY/uHeight);
    oColor[1]= cU((rPosX+2.)/uWidth,rPosY/uHeight);
    oColor[2]= cU((rPosX+4.)/uWidth,rPosY/uHeight);
    oColor[3]= cU((rPosX+6.)/uWidth,rPosY/uHeight);
    return oColor;
}

vec4 calculateV(){
    //V的采样，宽度是1:8，高度是1:2，U的位置高度偏移了1/4，一个点是4个V，采样区域是宽高位8*2
    float posX=floor(uWidth*v_TextureCoordinates.x);
    float posY=floor(uHeight*(v_TextureCoordinates.y-0.3125));
    //实际采样起始点对应图片的位置
    float rPosX=mod(posX*8.,uWidth);
    float rPosY=posY*16.+floor(posX*8./uWidth)*2.;
    vec4 oColor=vec4(0);
    oColor[0]=cV(rPosX/uWidth,rPosY/uHeight);
    oColor[1]=cV((rPosX+2.)/uWidth,rPosY/uHeight);
    oColor[2]=cV((rPosX+4.)/uWidth,rPosY/uHeight);
    oColor[3]=cV((rPosX+6.)/uWidth,rPosY/uHeight);
    return oColor;
}

void main() {
    if(v_TextureCoordinates.y<=0.2500){
        gl_FragColor=calculateY();
    }else if(v_TextureCoordinates.y <= 0.3125){
        gl_FragColor=calculateU();
    }else if(v_TextureCoordinates.y <= 0.3750){
        gl_FragColor=calculateV();
    }else{
        gl_FragColor=vec4(0,0,0,0);
    }
}